===========
Placeholder
===========

.. autoapimodule:: pyinduct.placeholder
    :members:
    :no-imported-members:
    :undoc-members:
    :show-inheritance:
    :exclude-members: FieldVariable, TestFunction

    .. autoapiclass:: FieldVariable
        :undoc-members:
        :show-inheritance:

    .. autoapiclass:: TestFunction
        :undoc-members:
        :show-inheritance:
